@@ -269,6 +269,13 @@ class MACourt(Court):
       else:
         return str(self.name) + ' (' + self.address.city + ')'
     
+    def short_label_and_address(self):
+      """
+      Returns a markdown formatted string with the name and address of the court.
+      More concise version without description; suitable for a responsive case.
+      """
+      return '**' + self.short_label() + '**' + '[BR]' + self.address.on_one_line()
+    
     def short_description(self):
       """
       Returns a Markdown formatted string that includes the disambiguated name and 
@@ -345,18 +352,25 @@ class MACourtList(DAList):
             'Land Court': self.matching_land_court,
             'Probate and Family Court': self.matching_probate_and_family_court,
             'Superior Court': self.matching_superior_court,
+            'Appeals Court': self.matching_appeals_court,
         }
 
         if isinstance(court_types, str):
+          if court_types in court_type_map:
             return court_type_map[court_types](address)
+          else:
+            return []
         elif isinstance(court_types, Iterable):
             matches = set()
             for court_type in court_types:
+              if court_type in court_type_map:
                 res =  court_type_map[court_type](address)
                 if isinstance(res, Iterable):
                     matches.update(res)
                 elif not res is None:
                     matches.add(res)
+              else:
+                return []
             return list(matches)
         else:
             raise Exception("NotAList")
@@ -374,7 +388,7 @@ class MACourtList(DAList):
 
     def load_courts(self, courts=['housing_courts','bmc','district_courts','superior_courts'], data_path='docassemble.MACourts:data/sources/'):
         """Load a set of courts into the MACourtList. Courts should be a list of names of JSON files in the data/sources directory.
-        Will fall back on loading courts directly from MassGov if the cached file doesn't exist. Available courts: district_courts, housing_courts,bmc,superior_courts,land_court,juvenile_courts,probate_and_family_courts"""
+        Will fall back on loading courts directly from MassGov if the cached file doesn't exist. Available courts: district_courts, housing_courts,bmc,superior_courts,land_court,juvenile_courts,probate_and_family_courts,appeals_court"""
         try:
             for court in courts:
                 self.load_courts_from_file(court, data_path=data_path)
@@ -414,6 +428,8 @@ class MACourtList(DAList):
             court_department = 'Land Court'
         elif court_name == 'probate_and_family_courts':
             court_department = 'Probate and Family Court'
+        elif court_name == "appeals_court":
+            court_department = "Appeals Court"
 
         for item in courts:
             # translate the dictionary data into an MACourt
@@ -455,6 +471,8 @@ class MACourtList(DAList):
             court_department = 'Land Court'
         elif court_name == 'probate_and_family_courts':
             court_department = 'Probate and Family Court'
+        elif court_name == "appeals_court":
+            court_department = "Appeals Court"            
 
         path = path_and_mimetype(os.path.join(data_path,json_path+'.json'))[0]
 
@@ -635,8 +653,10 @@ class MACourtList(DAList):
             matches.append("Hampden Probate and Family Court")
         if (address_to_compare.county.lower() == "hampshire county") or (address_to_compare.city.lower() in ["amherst", "belchertown", "chesterfield", "cummington", "easthampton", "goshen", "granby", "hadley", "hatfield", "huntington", "middlefield", "northampton", "pelham", "plainfield", "south hadley", "southamptom", "ware", "westhampton", "williamsburg", "worthington"]):
             matches.append("Hampshire Probate and Family Court")
-        if (address_to_compare.county.lower() == "middlesex county") or (address_to_compare.city.lower() in ["acton", "arlington", "ashby", "ashland", "ayer", "bedford", "belmont", "billerica", "boxborough", "burlington", "cambridge", "carlisle", "chelmsford", "concord", "dracut", "dunstable", "everett", "framingham", "groton", "holliston", "hopkinton", "hudson", "lexington", "lincoln", "littleton", "lowell", "malden", "marlborough","marlboro", "maynard", "medford", "melrose", "natick", "newton", "north reading", "pepperell", "reading", "sherborn", "shirley", "somerville", "stoneham", "stow", "sudbury", "tewksbury", "townsend", "tyngsborough", "wakefield", "waltham", "watertown", "wayland", "westford", "weston", "wilmington", "winchester", "woburn"]):
-            matches.append("Middlesex Probate and Family Court")
+        if (address_to_compare.county.lower() == "middlesex county") and (address_to_compare.city.lower() in ["arlington","belmont","cambridge","everett","lexington","malden","medford","melrose","newton","somerville","stoneham","wakefield","waltham","watertown","weston","winchester","woburn"]):
+            matches.append("Middlesex Probate and Family Court - South")
+        if (address_to_compare.county.lower() == "middlesex county") and (address_to_compare.city.lower() in ["acton","ashby","ashland","ayer","bedford","billerica","boxborough","burlington","carlisle","chelmsford","concord","dracut","dunstable","framingham","groton","holliston","hopkinton","hudson","lincoln","littleton","lowell","marlborough","maynard","natick","northreading","pepperrell","reading","sherborn","shirley","stow","sudbury","tewksbury","townsend","tyngsborough","wayland","westford","wilmington"]):
+            matches.append("Middlesex Probate and Family Court - North")	
         if (address_to_compare.county.lower() == "nantucket county") or (address_to_compare.city.lower() in ["nantucket"]):
             matches.append("Nantucket Probate and Family Court")
         if (address_to_compare.county.lower() == "norfolk county") or (address_to_compare.city.lower() in ["avon", "bellingham", "braintree", "brookline", "canton", "cohasset", "dedham", "dover", "foxborough", "franklin", "holbrook", "medfield", "medway", "millis", "milton", "needham", "norfolk", "norwood", "plainville", "quincy", "randolph", "sharon", "stoughton", "walpole", "wellesley", "westwood", "weymouth", "wrentham"]):
@@ -712,7 +732,11 @@ class MACourtList(DAList):
     def matching_land_court(self, address):
         """There's currently only one Land Court"""
         return next((court for court in self.elements if court.name.rstrip().lower() == 'land court'),None)
-
+      
+    def matching_appeals_court(self, address):
+        """One appeals court"""
+        return next((court for court in self.elements if court.name.rstrip().lower() == 'massachusetts appeals court'),None)
+      
     def matching_district_court(self, address):
         """Return list of MACourts representing the District Court(s) serving the given address"""
         court_name = self.matching_district_court_name(address)
